Split 'summary' manpages into section 7 (misc).

R=stip@chromium.org
BUG=

Review URL: https://codereview.chromium.org/212593006

git-svn-id: svn://svn.chromium.org/chrome/trunk/tools/depot_tools@259655 0039d316-1c4b-4281-b951-d872f2087c98
diff --git a/docs/html/depot_tools.html b/docs/html/depot_tools.html
index 0382625..c395ec8 100644
--- a/docs/html/depot_tools.html
+++ b/docs/html/depot_tools.html
@@ -4,7 +4,7 @@
 <head>
 <meta http-equiv="Content-Type" content="application/xhtml+xml; charset=UTF-8" />
 <meta name="generator" content="AsciiDoc 8.6.9" />
-<title>depot_tools(1)</title>
+<title>depot_tools(7)</title>
 <style type="text/css">
 /* Shared CSS for AsciiDoc xhtml11 and html5 backends */
 
@@ -741,7 +741,7 @@
 <body class="manpage">
 <div id="header">
 <h1>
-depot_tools(1) Manual Page
+depot_tools(7) Manual Page
 </h1>
 <h2>NAME</h2>
 <div class="sectionbody">
@@ -885,7 +885,7 @@
 <div id="footnotes"><hr /></div>
 <div id="footer">
 <div id="footer-text">
-Last updated 2014-03-25 15:09:11 PDT
+Last updated 2014-03-26 03:27:50 PDT
 </div>
 </div>
 </body>
diff --git a/docs/man1/depot_tools.1 b/docs/man7/depot_tools.7
similarity index 93%
rename from docs/man1/depot_tools.1
rename to docs/man7/depot_tools.7
index 663e8bf..7fd2128 100644
--- a/docs/man1/depot_tools.1
+++ b/docs/man7/depot_tools.7
@@ -1,13 +1,13 @@
 '\" t
 .\"     Title: depot_tools
 .\"    Author: [FIXME: author] [see http://docbook.sf.net/el/author]
-.\" Generator: DocBook XSL Stylesheets v1.78.1 <http://docbook.sf.net/>
-.\"      Date: 03/25/2014
+.\" Generator: DocBook XSL Stylesheets v1.76.1 <http://docbook.sf.net/>
+.\"      Date: 03/26/2014
 .\"    Manual: Chromium depot_tools Manual
-.\"    Source: depot_tools 207bff1
+.\"    Source: depot_tools 9c0c59f
 .\"  Language: English
 .\"
-.TH "DEPOT_TOOLS" "1" "03/25/2014" "depot_tools 207bff1" "Chromium depot_tools Manual"
+.TH "DEPOT_TOOLS" "7" "03/26/2014" "depot_tools 9c0c59f" "Chromium depot_tools Manual"
 .\" -----------------------------------------------------------------
 .\" * Define some portability stuff
 .\" -----------------------------------------------------------------
diff --git a/docs/src/depot_tools.txt b/docs/src/depot_tools.txt
index f90c06b..b25052e 100644
--- a/docs/src/depot_tools.txt
+++ b/docs/src/depot_tools.txt
@@ -1,4 +1,4 @@
-depot_tools(1)
+depot_tools(7)
 ==============
 
 NAME
diff --git a/docs/src/make_docs.sh b/docs/src/make_docs.sh
index c64992c..5c0240d 100755
--- a/docs/src/make_docs.sh
+++ b/docs/src/make_docs.sh
@@ -50,15 +50,15 @@
 wq
 EOF
 
   # fix Makefile to include non-_-prefixed files as MAN1 entries
   {
     shopt -s extglob
     echo H
-    echo 16
+    echo 35
     for x in "$(echo !(git-*|_*).txt)"
     do
       echo i
-      echo MAN1_TXT += $x
+      echo MAN7_TXT += $x
       echo .
     done
     echo wq
@@ -132,6 +132,7 @@
   } > __${category}.txt
 done
 
+JOBS=0
 HTML_TARGETS=()
 MAN_TARGETS=()
 for x in *.txt *.css
@@ -147,7 +148,13 @@
   if [[ ${x:0:1} != _ && ${x:(-4)} == .txt ]]
   then
     HTML_TARGETS+=("${x%%.txt}.html")
-    MAN_TARGETS+=("${x%%.txt}.1")
+    if [[ ${x:0:3} == git ]]
+    then
+      MAN1_TARGETS+=("${x%%.txt}.1")
+    else
+      MAN7_TARGETS+=("${x%%.txt}.7")
+    fi
+    JOBS=$[$JOBS + 2]
   fi
 done
 
@@ -164,7 +171,7 @@
 (
   export GIT_DIR="$(git rev-parse --git-dir)" &&
   cd git/Documentation &&
-  make -j"$[${#MAN_TARGETS} + ${#HTML_TARGETS}]" "${MAN_TARGETS[@]}" "${HTML_TARGETS[@]}"
+  make -j"$JOBS" "${MAN1_TARGETS[@]}" "${MAN7_TARGETS[@]}" "${HTML_TARGETS[@]}"
 )
 
 for x in "${HTML_TARGETS[@]}"
@@ -173,8 +180,14 @@
   tr -d '\015' <"git/Documentation/$x"  >"../html/$x"
 done
 
-for x in "${MAN_TARGETS[@]}"
+for x in "${MAN1_TARGETS[@]}"
 do
   echo Copying ../man1/$x
   cp "git/Documentation/$x" ../man1
+done
+
+for x in "${MAN7_TARGETS[@]}"
+do
+  echo Copying ../man7/$x
+  cp "git/Documentation/$x" ../man7
 done
\ No newline at end of file
@@ -50,15 +50,15 @@
 EOF
 
-  # fix Makefile to include non-_-prefixed files as MAN1 entries
+  # fix Makefile to include non-_-prefixed files as MAN7 entries
   {
     shopt -s extglob